@@ -1,15 +1,14 @@
 """
 ldap - base module
-written by Michael Stroeder <michael@stroeder.com>
 
 See http://python-ldap.sourceforge.net for details.
 
-$Id: __init__.py,v 1.52 2007/03/22 23:11:56 stroeder Exp $
+$Id: __init__.py,v 1.58 2008/03/26 16:43:13 stroeder Exp $
 """
 
 # This is also the overall release version number
 
-__version__ = '2.3'
+__version__ = '2.3.4'
 
 import sys
 
@@ -48,3 +47,9 @@ _ldap_module_lock = LDAPLock()
 from functions import open,initialize,init,get_option,set_option
 
 from ldap.dn import explode_dn,explode_rdn
+
+# More constants
+
+# For compability of 2.3 and 2.4 OpenLDAP API
+OPT_DIAGNOSTIC_MESSAGE = OPT_ERROR_STRING
+
