@@ -1,10 +1,9 @@
 """
 schema.py - support for subSchemaSubEntry information
-written by Michael Stroeder <michael@stroeder.com>
 
 See http://python-ldap.sourceforge.net for details.
 
-\$Id: models.py,v 1.25 2004/06/21 18:04:09 stroeder Exp $
+\$Id: models.py,v 1.33 2008/03/26 16:42:22 stroeder Exp $
 """
 
 import UserDict,ldap.cidict
@@ -22,7 +21,6 @@ if __debug__:
 NOT_HUMAN_READABLE_LDAP_SYNTAXES = {
   '1.3.6.1.4.1.1466.115.121.1.4':None,  # Audio
   '1.3.6.1.4.1.1466.115.121.1.5':None,  # Binary
-  '1.3.6.1.4.1.1466.115.121.1.6':None,  # Bit String
   '1.3.6.1.4.1.1466.115.121.1.8':None,  # Certificate
   '1.3.6.1.4.1.1466.115.121.1.9':None,  # Certificate List
   '1.3.6.1.4.1.1466.115.121.1.10':None, # Certificate Pair
@@ -43,7 +41,7 @@ class SchemaElement:
   
   def __init__(self,schema_element_str=None):
     if schema_element_str:
-      l = split_tokens(schema_element_str)
+      l = split_tokens(schema_element_str,self.token_defaults)
       self.set_id(l[1])
       assert type(self.get_id())==StringType
       d = extract_tokens(l,self.token_defaults)
@@ -127,9 +125,9 @@ class ObjectClass(SchemaElement):
       self.kind = 1
     elif d['AUXILIARY']!=None:
       self.kind = 2
-    if self.kind==0:
-      # STRUCTURAL object classes are sub-classes of 'top' be default
-      self.sup = d['SUP'] or ('top',)
+    if self.kind==0 and not d['SUP'] and self.oid!='2.5.6.0':
+      # STRUCTURAL object classes are sub-classes of 'top' by default
+      self.sup = ('top',)
     else:
       self.sup = d['SUP']
     assert type(self.names)==TupleType
@@ -145,7 +143,7 @@ class ObjectClass(SchemaElement):
     result = [str(self.oid)]
     result.append(self.key_list('NAME',self.names,quoted=1))
     result.append(self.key_attr('DESC',self.desc,quoted=1))
-    result.append(self.key_list('SUP',self.sup))
+    result.append(self.key_list('SUP',self.sup,sep=' $ '))
     result.append({0:'',1:' OBSOLETE'}[self.obsolete])
     result.append({0:' STRUCTURAL',1:' ABSTRACT',2:' AUXILIARY'}[self.kind])
     result.append(self.key_list('MUST',self.must,sep=' $ '))
@@ -248,7 +246,7 @@ class AttributeType(SchemaElement):
     result = [str(self.oid)]
     result.append(self.key_list('NAME',self.names,quoted=1))
     result.append(self.key_attr('DESC',self.desc,quoted=1))
-    result.append(self.key_list('SUP',self.sup))
+    result.append(self.key_list('SUP',self.sup,sep=' $ '))
     result.append({0:'',1:' OBSOLETE'}[self.obsolete])
     result.append(self.key_attr('EQUALITY',self.equality))
     result.append(self.key_attr('ORDERING',self.ordering))
@@ -565,6 +563,9 @@ class Entry(UserDict.UserDict):
     for key in dict.keys():
       self[key] = dict[key]
 
+  def __contains__(self,key):
+    return self.has_key(self,key)
+
   def __getitem__(self,nameoroid):
     return self.data[self._at2key(nameoroid)]
 
